##  Adding Relations
Relations between fact sheets capture how various architectural elements are connected, interact, or depend on each other across your enterprise landscape. When adding or editing relations to other fact sheets, you can select multiple fact sheets at once to work more efficiently.
To add relations, do the following:
  1. Hover over the section where you want to add or edit relations to other fact sheets.
  2. Click the + Add in the upper right corner.
  3. Clicking on the relation field opens a drop-down list of fact sheets you can relate to. You can switch between list view and hierarchy view. Hierarchy view helps you understand parent-child relationships and makes it easier to select the right fact sheet.
![Switching Between Hierarchy View and List View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod5160e1751064e5a9e935975438c49c1_HiRes.png)
Switching Between Hierarchy View and List View
  4. Select one or more fact sheets.
  5. Fill in the ‘fields on relation’ as needed for all the selected fact sheets simultaneously.
  6. Click Save or use the Save & Next button to move automatically to the next section.


**Tip**
When relating business capabilities to organizations with child fact sheets (such as level 2 organizations), establish the relation separately for each individual organization. This approach allows you to manage and adjust business capabilities for each child organization independently. If you assign business capabilities to the parent organization, you won’t be able to adjust them individually for the child organizations.
**Tip**
  * To preview a relation in the relations explorer, hover over a linked fact sheet, then click See on Explorer on the right.
  * To preview a linked fact sheet in the right-side pane, click the fact sheet name.
  * To open a linked fact sheet in a new tab, hover over the fact sheet, then click the arrow button on the right.
